@@ -8,6 +8,10 @@ module FactoryBot
       def result(evaluation)
         evaluation.hash
       end
+
+      def to_sym
+        :attributes_for
+      end
     end
   end
 end
