@@ -15,7 +15,7 @@ module FactoryBot
         def factory(name, options = {}, &block)
           factory = Factory.new(name, options)
           proxy = FactoryBot::DefinitionProxy.new(factory.definition)
-          proxy.instance_eval(&block) if block_given?
+          proxy.instance_eval(&block) if block
 
           Internal.register_factory(factory)
 
@@ -33,29 +33,17 @@ module FactoryBot
           Internal.register_trait(Trait.new(name, &block))
         end
 
-        def to_create(&block)
-          FactoryBot.to_create(&block)
-        end
-
-        def skip_create
-          FactoryBot.skip_create
-        end
-
-        def initialize_with(&block)
-          FactoryBot.initialize_with(&block)
-        end
-
         def self.run(block)
           new.instance_eval(&block)
         end
 
-        delegate :before, :after, :callback, to: :configuration
-
-        private
-
-        def configuration
-          Internal.configuration
-        end
+        delegate :after,
+          :before,
+          :callback,
+          :initialize_with,
+          :skip_create,
+          :to_create,
+          to: FactoryBot::Internal
       end
 
       class ModifyDSL
