@@ -15,7 +15,7 @@ module FactoryBot
     end
 
     delegate :add_callback, :declare_attribute, :to_create, :define_trait, :constructor,
-      :callbacks, :attributes, to: :@definition
+      :callbacks, :attributes, :klass, :klass=, to: :@definition
 
     def names
       [@name]
